@@ -12,4 +12,8 @@ typedef sqlite3Ruby * sqlite3RubyPtr;
 
 void init_sqlite3_database();
 
+#ifndef RB_GC_GUARD
+#define RB_GC_GUARD(x) x
+#endif
+
 #endif
